% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BiocPackage-class.R
\docType{data}
\name{BiocPackage-class}
\alias{BiocPackage-class}
\alias{.BiocPackage}
\alias{BiocPackage}
\title{A class for representing files in a Bioconductor package}
\format{
An object of class \code{BiocPackage} of length 1.
}
\usage{
.BiocPackage
}
\value{
An object of class `BiocPackage`
}
\description{
The BiocPackage class is used to represent a Bioconductor
  package. It is used by BiocCheck to store information about the package
  being checked. The class has several methods to identify the type of
  package, check for common issues, and store metadata about the package.
}
\section{Fields}{

\describe{
\item{\code{isValid}}{`logical` indicating whether the package's `DESCRIPTION` file
was able to be read without any errors}

\item{\code{isTar}}{`logical` indicating whether the package is a tarball}

\item{\code{isSourceDir}}{`logical` indicating whether the package being checked is
from a source directory}

\item{\code{isInfrastructure}}{`logical` indicating whether the package is an
Bioconductor infrastructure package based on the `biocViews` field}

\item{\code{usesRoxygen}}{`logical` indicating whether the package uses `roxygen2`
documentation}

\item{\code{usesRdpack}}{`logical` indicating whether the package uses `Rdpack`
package}

\item{\code{DESCRIPTION}}{`matrix` containing the DCF contents of the `DESCRIPTION`
file}

\item{\code{dependencies}}{`character` vector of package dependencies}

\item{\code{readError}}{`character` error message if the `DESCRIPTION` file could
not be read}

\item{\code{packageVersion}}{`character` version of the package}

\item{\code{packageType}}{`character` indicating the type of package based on the
`biocViews` field; can be `NA_character_` there are invalid `biocViews`
terms}

\item{\code{sourceDir}}{`character` path to the source directory}

\item{\code{vignettesDir}}{`character` path to the vignettes directory}

\item{\code{RSources}}{`character` vector of R source files}

\item{\code{VigSources}}{`character` vector of vignette source files}

\item{\code{manSources}}{`character` vector of Rd source files}

\item{\code{BiocCheckDir}}{`character` path to the directory where the package
BiocCheck logs are written}

\item{\code{packageName}}{`character` name of the package}

\item{\code{tarFilename}}{`character` filename of the tarball}

\item{\code{metadata}}{`list` containing metadata about the package}
}}

\examples{

# Create a BiocPackage object
packageDirectory <- "path/to/package"
if (dir.exists(packageDirectory))
    .bioctest <- .BiocPackage$initialize(packageDirectory)

.bioctest <- BiocCheck:::.BiocPackage

.bioctest$DESCRIPTION

}
\keyword{internal}
